==> libgnomedb-1.9.102.tar.bz2: libgnomedb-1.9.102/libgnomedb/data-entries/gnome-db-entry-time.h <==
/* gnome-db-entry-time.h
 *
 * Copyright (C) 2003 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#ifndef __GNOME_DB_ENTRY_TIME_H_
#define __GNOME_DB_ENTRY_TIME_H_

#include "gnome-db-entry-wrapper.h"

G_BEGIN_DECLS

#define GNOME_DB_TYPE_ENTRY_TIME          (gnome_db_entry_time_get_type())
#define GNOME_DB_ENTRY_TIME(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_time_get_type(), GnomeDbEntryTime)
#define GNOME_DB_ENTRY_TIME_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_time_get_type (), GnomeDbEntryTimeClass)
#define IS_GNOME_DB_ENTRY_TIME(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_time_get_type ())


typedef struct _GnomeDbEntryTime GnomeDbEntryTime;
typedef struct _GnomeDbEntryTimeClass GnomeDbEntryTimeClass;
typedef struct _GnomeDbEntryTimePrivate GnomeDbEntryTimePrivate;


/* struct for the object's data */
struct _GnomeDbEntryTime
{
	GnomeDbEntryWrapper              object;
	GnomeDbEntryTimePrivate         *priv;
};

/* struct for the object's class */
struct _GnomeDbEntryTimeClass
{
	GnomeDbEntryWrapperClass         parent_class;
};

GType        gnome_db_entry_time_get_type        (void);
GtkWidget   *gnome_db_entry_time_new             (GdaDataHandler *dh, GdaValueType type);


G_END_DECLS

#endif

==> libgnomedb-3.1.1.tar.bz2: libgnomedb-3.1.1/libgnomedb/data-entries/gnome-db-entry-time.h <==
/* gnome-db-entry-time.h
 *
 * Copyright (C) 2003 - 2006 Vivien Malerba
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#ifndef __GNOME_DB_ENTRY_TIME_H_
#define __GNOME_DB_ENTRY_TIME_H_

#include "gnome-db-entry-common-time.h"

G_BEGIN_DECLS

#define GNOME_DB_TYPE_ENTRY_TIME          (gnome_db_entry_time_get_type())
#define GNOME_DB_ENTRY_TIME(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_time_get_type(), GnomeDbEntryTime)
#define GNOME_DB_ENTRY_TIME_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_time_get_type (), GnomeDbEntryTimeClass)
#define GNOME_DB_IS_ENTRY_TIME(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_time_get_type ())


typedef struct _GnomeDbEntryTime GnomeDbEntryTime;
typedef struct _GnomeDbEntryTimeClass GnomeDbEntryTimeClass;
typedef struct _GnomeDbEntryTimePrivate GnomeDbEntryTimePrivate;


/* struct for the object's data */
struct _GnomeDbEntryTime
{
	GnomeDbEntryCommonTime           object;
};

/* struct for the object's class */
struct _GnomeDbEntryTimeClass
{
	GnomeDbEntryCommonTimeClass      parent_class;
};

GType        gnome_db_entry_time_get_type        (void) G_GNUC_CONST;
GtkWidget   *gnome_db_entry_time_new             (GdaDataHandler *dh);


G_END_DECLS

#endif
